import React, { useState, useEffect } from 'react';
import Context from './Context';

var Provider = function Provider(_ref) {
  var children = _ref.children,
      _ref$persistKey = _ref.persistKey,
      persistKey = _ref$persistKey === void 0 ? 'theme' : _ref$persistKey,
      appConfig = _ref.appConfig;

  var _ref2 = appConfig || {},
      themeConfig = _ref2.theme;

  var _ref3 = themeConfig || {},
      defaultThemeID = _ref3.defaultThemeID,
      defaultIsDarkMode = _ref3.defaultIsDarkMode,
      defaultIsRTL = _ref3.defaultIsRTL;

  var _useState = useState(defaultThemeID),
      themeID = _useState[0],
      setThemeID = _useState[1];

  var _useState2 = useState(defaultIsDarkMode),
      isDarkMode = _useState2[0],
      setIsDarkMode = _useState2[1];

  var _useState3 = useState(defaultIsRTL),
      isRTL = _useState3[0],
      setIsRTL = _useState3[1];

  var themeIDKey = persistKey + ":themeID";
  var isDarkModeKey = persistKey + ":isDarkMode";
  var isRTLKey = persistKey + ":isRTL";

  var toggleThisTheme = function toggleThisTheme(mode) {
    if (mode === 'isRTL') setIsRTL(!isRTL);
    if (mode === 'isDarkMode') setIsDarkMode(!isDarkMode);
  };

  useEffect(function () {
    var persistThemeID = localStorage.getItem(themeIDKey);
    var persistIsDarkMode = localStorage.getItem(isDarkModeKey);
    var persistIsRTL = localStorage.getItem(isRTLKey);

    if (persistThemeID) {
      setThemeID(persistThemeID);
    }

    if (persistIsDarkMode) {
      // convert to boolean
      setIsDarkMode(persistIsDarkMode === 'true');
    }

    if (persistIsRTL) {
      //have to convert the stored string back to boolean
      setIsRTL(persistIsRTL === 'true' ? true : false);
    }
  }, [themeIDKey, isDarkModeKey, isRTLKey]);
  useEffect(function () {
    try {
      localStorage.setItem(themeIDKey, themeID);
    } catch (error) {
      console.warn(error);
    }
  }, [themeID, themeIDKey]);
  useEffect(function () {
    try {
      localStorage.setItem(isDarkModeKey, isDarkMode);
    } catch (error) {
      console.warn(error);
    }
  }, [isDarkMode, isDarkModeKey]);
  useEffect(function () {
    try {
      localStorage.setItem(isRTLKey, isRTL);
    } catch (error) {
      console.warn(error);
    }
  }, [isRTL, isRTLKey]);
  return /*#__PURE__*/React.createElement(Context.Provider, {
    value: {
      themeID: themeID,
      setThemeID: setThemeID,
      isDarkMode: isDarkMode,
      isRTL: isRTL,
      toggleThisTheme: toggleThisTheme
    }
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      direction: isRTL ? 'rtl' : 'ltr'
    }
  }, children));
};

export default Provider;